@@ -22,7 +22,6 @@
 #include <QObject>
 #include <QMap>
 #include <QVariant>
-#include <QPointer>
 
 #include "xrandrmode.h"
 #include "output.h"
@@ -90,6 +89,7 @@ private:
     mutable QByteArray m_edid;
     unsigned int m_widthMm;
     unsigned int m_heightMm;
+    bool m_hotplugModeUpdate = false;
     XRandRCrtc *m_crtc;
 };
 
